osc\_recorder package
=====================

Submodules
----------

osc\_recorder.base module
-------------------------

.. automodule:: osc_recorder.base
   :members:
   :undoc-members:
   :show-inheritance:

osc\_recorder.collector module
------------------------------

.. automodule:: osc_recorder.collector
   :members:
   :undoc-members:
   :show-inheritance:

osc\_recorder.osc\_utils module
-------------------------------

.. automodule:: osc_recorder.osc_utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: osc_recorder
   :members:
   :undoc-members:
   :show-inheritance:
